{
  pkgs,
  buildRoot,
  projectDefinition,
  ...
}: let
  ciJobToken = builtins.getEnv "CI_JOB_TOKEN";
  gitCommit =
    if ciJobToken == ""
    then (builtins.getFlake "git+https://gitlab.schukai.com/schukai/entwicklung/nix-flakes").packages.${builtins.currentSystem}.git-commit
    else "";

  goPkgReleaseData = import ./project.nix;
  goPkgName = goPkgReleaseData.name;
  goPkgMnemonic = goPkgReleaseData.mnemonic;
in
  pkgs.writeTextFile {
    name = "Taskfile.yaml";
    text = ''
      ## THIS FILE IS AUTOGENERATED. DO NOT EDIT THIS FILE DIRECTLY.
      version: '3'

      tasks:
          build-image:
                desc: Build the docker image
                aliases:
                  - bi
                vars:
                cmds:
                  - update-hashes --file={{.TASKFILE_DIR}}
                  - build-image
                sources:
                  - '{{.TASKFILE_DIR}}/source/service/**/*.go'
                  - '{{.TASKFILE_DIR}}/source/service/**/*.mod'
                  - '{{.TASKFILE_DIR}}/**/*.nix'
                silent: true

          git-commit:
                desc: Commit changes to git
                cmds:
                  - ${gitCommit}/bin/git-commit
                silent: true

          check-licenses:
                desc: Check license headers of Go files.
                silent: true
                cmds:
                  - check-licences

          default:
                aliases: [d, help]
                cmds:
                  - task --list
                silent: true
      ## THIS FILE IS AUTOGENERATED. DO NOT EDIT THIS FILE DIRECTLY.

    '';
  }
