{
  pkgs,
  buildRoot,
  projectDefinition,
  ...
}: let
  serviceSourcePath = "${buildRoot}/services/";
  licensesPath = "${buildRoot}/documentation/licenses/";
  common = import ./common.nix {inherit pkgs;};
  moduleGoPath = projectDefinition.modulePath;
in ''
  #!${pkgs.bash}/bin/bash
  set -x
  ${common}

  mkdir -p "${licensesPath}" || true

  if [[ ! -d "${licensesPath}" ]]; then
   if [[ ! -e "${licensesPath}" ]]; then
       echo_fail "Could not create directory ${licensesPath}"
       exit 1
   fi
   echo_fail "${licensesPath} is not a directory"
   exit 1
  fi

  echo_section "Update licenses"
  if ! cd "${serviceSourcePath}/" ; then
   echo_fail "Could not change directory to ${serviceSourcePath}/"
   exit 1
  fi

  pwd

  if ! ${pkgs.go-licenses}/bin/go-licenses save "${moduleGoPath}" \
          --ignore="gitlab.schukai.com"  \
          --force   \
          --save_path="${licensesPath}" \
          ; then
  echo_fail "Could not update licenses"
  exit 1
  fi

  cd ${buildRoot}

  if [[ ! -d "${licensesPath}" ]] || [[ -z "$(ls -A ${licensesPath})" ]]; then
   echo_ok "There are no licenses"
   exit 0
  fi

  echo_ok "Licenses updated"


''
